@@ -1,6 +1,5 @@
 use bigdecimal::{BigDecimal, ParseBigDecimalError};
 use chrono::FixedOffset;
-use internship::IStr;
 use itertools::Itertools;
 use num_bigint::{BigInt, ParseBigIntError};
 use ordered_float::OrderedFloat;
@@ -15,19 +14,16 @@ use uuid::Uuid;
 
 /// A keyword, as described in EDN data model, is identifier which should
 /// "designate itself".
-///
-/// Because its contents are interned, cloning and comparisons should be relatively
-/// cheap operations and construction relatively expensive.
 #[derive(Debug, Clone, Hash, Eq, PartialEq, Ord, PartialOrd)]
 pub struct Keyword {
-    namespace: Option<IStr>,
-    name: IStr,
+    namespace: Option<String>,
+    name: String,
 }
 
 impl Keyword {
     /// The namespace of the keyword, if there is one.
     pub fn namespace(&self) -> Option<&str> {
-        self.namespace.as_ref().map(|s| s.as_str())
+        self.namespace.as_deref()
     }
 
     /// The name of the keyword.
@@ -41,7 +37,7 @@ impl Keyword {
     pub fn from_name(name: &str) -> Keyword {
         Keyword {
             namespace: Option::None,
-            name: IStr::new(name),
+            name: name.to_string(),
         }
     }
 
@@ -51,8 +47,8 @@ impl Keyword {
     /// given would be valid EDN.
     pub fn from_namespace_and_name(namespace: &str, name: &str) -> Keyword {
         Keyword {
-            namespace: Option::Some(IStr::new(namespace)),
-            name: IStr::new(name),
+            namespace: Option::Some(namespace.to_string()),
+            name: name.to_string(),
         }
     }
 }
@@ -69,19 +65,16 @@ impl Display for Keyword {
 }
 
 /// A symbol, as described in EDN data model, is an identifier.
-///
-/// Because its contents are interned, cloning and comparisons should be relatively
-/// cheap operations and construction relatively expensive.
 #[derive(Debug, Clone, Hash, Eq, PartialEq, Ord, PartialOrd)]
 pub struct Symbol {
-    namespace: Option<IStr>,
-    name: IStr,
+    namespace: Option<String>,
+    name: String,
 }
 
 impl Symbol {
     /// The namespace of the symbol, if there is one.
     pub fn namespace(&self) -> Option<&str> {
-        self.namespace.as_ref().map(|s| s.as_str())
+        self.namespace.as_deref()
     }
 
     /// The name of the symbol.
@@ -95,7 +88,7 @@ impl Symbol {
     pub fn from_name(name: &str) -> Symbol {
         Symbol {
             namespace: Option::None,
-            name: IStr::new(name),
+            name: name.to_string(),
         }
     }
 
@@ -105,8 +98,8 @@ impl Symbol {
     /// given would be valid EDN.
     pub fn from_namespace_and_name(namespace: &str, name: &str) -> Symbol {
         Symbol {
-            namespace: Option::Some(IStr::new(namespace)),
-            name: IStr::new(name),
+            namespace: Option::Some(namespace.to_string()),
+            name: name.to_string(),
         }
     }
 }
@@ -560,18 +553,38 @@ trait ParseObserver {
     fn advance_one_char(&mut self, c: char);
 }
 
+struct NoOpParseObserver;
+
+impl ParseObserver for NoOpParseObserver {
+    fn start_parsing_vector(&mut self) {}
+
+    fn start_parsing_list(&mut self) {}
+
+    fn start_parsing_map(&mut self) {}
+
+    fn start_parsing_set(&mut self) {}
+
+    fn start_parsing_string(&mut self) {}
+
+    fn start_parsing_atom(&mut self) {}
+
+    fn stop_parsing_current(&mut self) {}
+
+    fn advance_one_char(&mut self, _c: char) {}
+}
+
 /// An element of context about what the parser was doing when an error was detected.
 #[derive(Debug, Copy, Clone, Eq, PartialEq)]
 pub enum Context {
     /// The parser started parsing a vector at the given row and col.
     ParsingVector { row: usize, col: usize },
-    /// The parser started parsing a vector at the given row and col.
+    /// The parser started parsing a list at the given row and col.
     ParsingList { row: usize, col: usize },
-    /// The parser started parsing a vector at the given row and col.
+    /// The parser started parsing a map at the given row and col.
     ParsingMap { row: usize, col: usize },
-    /// The parser started parsing a vector at the given row and col.
+    /// The parser started parsing a set at the given row and col.
     ParsingSet { row: usize, col: usize },
-    /// The parser started parsing a vector at the given row and col.
+    /// The parser started parsing a string at the given row and col.
     ParsingString { row: usize, col: usize },
     /// The parser started parsing an "atom" at the given row and col.
     ///
@@ -1398,8 +1411,12 @@ impl<Iter: Iterator<Item = char>> Iterator for Parser<Iter> {
     type Item = Result<Value, ParserError>;
 
     fn next(&mut self) -> Option<Self::Item> {
-        let mut context = ContextStackerObserver::new();
-        match parse_helper(&mut self.iter, ParserState::Begin, &mut context, &self.opts) {
+        match parse_helper(
+            &mut self.iter,
+            ParserState::Begin,
+            &mut NoOpParseObserver,
+            &self.opts,
+        ) {
             Err(error) => {
                 if error == ParserError::EmptyInput {
                     None
